YEAR = 0
MONTH = 1
DAY = 2
HOUR = 3
MINUTE = 4
SECOND = 5
MILLISECOND = 6


class BaseLocale():
    def __init__(self):
        pass

    def relative(self, target, number):
        pass

    def past(self, time):
        pass

    def future(self, time):
        pass